.. raw:: html

    <object data="_static/pymedphys_title.svg" type="image/svg+xml" class="title-logo"></object>

.. include:: README.rst
   :start-after: START_OF_DOCS_IMPORT
   :end-before: END_OF_DOCS_IMPORT

.. _`Release Notes`: release-notes.html
.. _`Statement of Need`: statement-of-need.html

.. _`Quick Start Guide`: users/get-started/quick-start.html
.. _`get started`: users/get-started/index.html
.. _`how-to guides`: users/howto/index.html
.. _`background information`: users/background/index.html
.. _`Technical Reference`: users/ref/index.html
.. _`workstation setup guides`: contrib/setups/index.html
.. _`repository information`: contrib/info/index.html
.. _`tips & tricks`: contrib/tips/index.html

.. toctree::
    :hidden:
    :maxdepth: 3

    overview
    statement-of-need
    release-notes


.. toctree::
    :hidden:
    :maxdepth: 3
    :caption: Users Guide

    users/get-started/index
    users/howto/index
    users/background/index
    users/ref/index


.. toctree::
    :hidden:
    :maxdepth: 3
    :caption: Contributors Guide

    contrib/index
    contrib/info/index
    contrib/setups/index
    contrib/tips/index
    contrib/dive/index
